/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.qpid.server.security.access.plugins;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.core.IsEqual.equalTo;
import static org.junit.Assert.assertThat;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import java.util.Collections;
import java.util.Map;

import org.junit.Test;

import org.apache.qpid.server.security.access.config.ObjectProperties;
import org.apache.qpid.server.security.access.config.Rule;
import org.apache.qpid.test.utils.UnitTestBase;

public class AclRuleImplTest extends UnitTestBase
{
    @Test
    public void testGetAttributes()
    {
        final Rule rule = mock(Rule.class);
        final Map<ObjectProperties.Property, String> expected =
                Collections.singletonMap(ObjectProperties.Property.NAME, getTestName());
        when(rule.getAttributes()).thenReturn(expected);

        final AbstractCommonRuleBasedAccessControlProvider.AclRuleImpl aclRule =
                new AbstractCommonRuleBasedAccessControlProvider.AclRuleImpl(rule);
        assertThat(aclRule.getAttributes(), is(equalTo(expected)));
        verify(rule).getAttributes();
    }

}
